@@ -25,6 +25,8 @@ use IO::CaptureOutput qw/capture/;
 use Probe::Perl ();
 use Test::More;
 
+use t::MockHomeDir;
+
 #--------------------------------------------------------------------------#
 # Fixtures
 #--------------------------------------------------------------------------#
@@ -34,10 +36,8 @@ my $make = $Config{make};
 
 my $temp_stdout = File::Temp->new() 
     or die "Couldn't make temporary file:$!\nIs your temp drive full?";
-my $temp_home = tempdir(
-        "CPAN-Reporter-testhome-XXXXXXXX", TMPDIR => 1, CLEANUP => 1
-) or die "Couldn't create temporary config dir: $!\nIs your temp drive full?";
-my $home_dir = File::Spec->rel2abs( $temp_home );
+
+my $home_dir = t::MockHomeDir::home_dir();
 my $config_dir = File::Spec->catdir( $home_dir, ".cpanreporter" );
 my $config_file = File::Spec->catfile( $config_dir, "config.ini" );
 
@@ -72,7 +72,7 @@ sub test_fake_config {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
     my %overrides = @_;
 
-    is( File::HomeDir::my_documents(), $home_dir,
+    is( File::HomeDir::my_documents(), t::MockHomeDir::home_dir(),
         "home directory mocked"
     ); 
     mkpath $config_dir;
@@ -84,7 +84,6 @@ sub test_fake_config {
     $tiny->{_}{email_from} = $bogus_email_from;
     $tiny->{_}{email_to} = $bogus_email_to; # failsafe
     $tiny->{_}{smtp_server} = $bogus_smtp;
-    $tiny->{_}{cc_author} = "yes";
     $tiny->{_}{send_report} = "yes";
     $tiny->{_}{send_duplicates} = "yes"; # tests often repeat same stuff
     for my $key ( keys %overrides ) {
@@ -119,10 +118,10 @@ sub test_grade_PL {
                 if ! $have_tool;
             
             my $tempd = _ok_clone_dist_dir( $case->{name} );
+            local $dist->{build_dir} = "$tempd";
             
             $t::Helper::sent_report = undef;
             $t::Helper::comments = undef;
-            @t::Helper::cc_list = ();
 
             my ($stdout, $stderr, $build_rc, $test_build_rc, 
                 $output, $exit_value, $rc);
@@ -236,7 +235,6 @@ sub test_grade_make {
 
             $t::Helper::sent_report = undef;
             $t::Helper::comments = undef;
-            @t::Helper::cc_list = ();
 
             my ($stdout, $stderr, $build_err, $test_build_rc, 
                 $output, $exit_value, $rc);
@@ -361,7 +359,6 @@ sub test_grade_test {
                 
             $t::Helper::sent_report = undef;
             $t::Helper::comments = undef;
-            @t::Helper::cc_list = ();
 
             my ($stdout, $stderr, $build_err, $test_build_rc);
 
@@ -468,10 +465,10 @@ HERE
 Thank you for uploading your work to CPAN.  However, attempting to
 test your distribution gave an inconclusive result.  
 
-This could be because you did not define tests, tests could not be 
-found, because your tests were interrupted before they finished, or 
-because the results of the tests could not be parsed.  You may wish to 
-consult the CPAN Testers Wiki:
+This could be because your distribution had an error during the make/build
+stage, did not define tests, tests could not be found, because your tests were
+interrupted before they finished, or because the results of the tests could not
+be parsed.  You may wish to consult the CPAN Testers Wiki:
 
 http://cpantest.grango.org/wiki/CPANAuthorNotes
 HERE
@@ -488,7 +485,7 @@ HERE
     
 );
 
-sub test_report_plan() { 14 };
+sub test_report_plan() { 13 };
 sub test_report {
     local $Test::Builder::Level = $Test::Builder::Level + 1;
 
@@ -603,15 +600,6 @@ sub test_report {
         "$label found output matches expected output"
     );
 
-    my @expected_cc;
-    my $author = $case->{dist}->author;
-    push @expected_cc, $author->id if defined $author && !$Config{perl_patchlevel};
-    is_deeply( 
-        [ @t::Helper::cc_list ], 
-        [ map { $_ . '@cpan.org' } @expected_cc ],
-        "$label cc list correct"
-    );
-
     return ($stdout, $stderr, $err, $test_output);
 };
 
@@ -633,6 +621,7 @@ sub test_dispatch {
     my %opt = @_;
 
     my $tempd = _ok_clone_dist_dir( $case->{name} );
+    local $case->{dist}{build_dir} = "$tempd";
                 
     my ($stdout, $stderr, $err) = _run_report( $case );
 
@@ -712,7 +701,6 @@ sub _run_report {
     
     $t::Helper::sent_report = undef;
     $t::Helper::comments = undef;
-    @t::Helper::cc_list = ();
 
     eval {
         capture sub {
@@ -758,15 +746,9 @@ sub _short_name {
 #--------------------------------------------------------------------------#
 
 BEGIN {
-    $INC{"File/HomeDir.pm"} = 1; # fake load
     $INC{"Test/Reporter.pm"} = 1; # fake load
 }
 
-package File::HomeDir;
-sub my_documents { return $home_dir };
-sub my_home { return $home_dir };
-sub my_data { return $home_dir };
-
 package Test::Reporter;
 use vars qw/$AUTOLOAD/;
 
@@ -781,7 +763,6 @@ sub comments { shift; $t::Helper::comments = shift }
 sub send { 
     shift; 
     $t::Helper::sent_report = $t::Helper::comments; 
-    @t::Helper::cc_list = ( @_ ); 
     return 1 
 } 
 
@@ -792,6 +773,20 @@ sub subject {
 }
 
 my %mocked_data;
+
+my @valid_transport = qw/Mail::Send Net::SMTP Net::SMTP::Auth HTTP/;
+
+sub transport {
+    my ($self) = shift;
+    if (@_) {
+        my $t = shift;
+        die __PACKAGE__ . ":transport: '$t' is invalid\n"
+            unless grep { $t eq $_ } @valid_transport;
+        $mocked_data{transport} = $t;
+    }
+    return $mocked_data{transport};
+}
+    
 sub AUTOLOAD {
     my $self = shift;
     if ( @_ ) {
